<?php

namespace Drupal\mollie\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class RedirectController.
 *
 * @package Drupal\mollie\Controller
 */
class RedirectController extends ControllerBase {

  /**
   * Redirects the visitor to the appropriate place after payment.
   *
   * @param string $context
   *   The type of context that requested the payment.
   * @param string $context_id
   *   The ID of the context that requested the payment.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Response that redirects to the appropriate place.
   */
  public function paymentRedirect(string $context, string $context_id): RedirectResponse {
    // Redirect to the payment collection by default.
    $url = Url::fromRoute('entity.mollie_payment.collection');

    switch ($context) {
      // TODO: Abstract this so that it is only known in Mollie for Drupal Commerce.
      case 'mollie_commerce':
        // Hand over control back to Drupal Commerce.
        $url = Url::fromRoute(
          'commerce_payment.checkout.return',
          [
            'commerce_order' => $context_id,
            'step' => 'payment',
          ]
        );
        break;

      default:
        break;
    }

    return new RedirectResponse($url->toString());
  }

}
